@@ -1,4 +1,4 @@
-from typing import Any, Optional, Union
+from typing import Any
 
 import pytest
 from sqlmodel import Field, SQLModel
@@ -8,7 +8,7 @@ def test_type_list_breaks() -> None:
     with pytest.raises(ValueError):
 
         class Hero(SQLModel, table=True):
-            id: Optional[int] = Field(default=None, primary_key=True)
+            id: int | None = Field(default=None, primary_key=True)
             tags: list[str]
 
 
@@ -16,7 +16,7 @@ def test_type_dict_breaks() -> None:
     with pytest.raises(ValueError):
 
         class Hero(SQLModel, table=True):
-            id: Optional[int] = Field(default=None, primary_key=True)
+            id: int | None = Field(default=None, primary_key=True)
             tags: dict[str, Any]
 
 
@@ -24,5 +24,5 @@ def test_type_union_breaks() -> None:
     with pytest.raises(ValueError):
 
         class Hero(SQLModel, table=True):
-            id: Optional[int] = Field(default=None, primary_key=True)
-            tags: Union[int, str]
+            id: int | None = Field(default=None, primary_key=True)
+            tags: int | str
